#' US Counties map in Geojson format (list)
#' 
#' This data comes from the \url{https://code.highcharts.com/mapdata/countries/us/us-all-all.js}
#' and is used in highmaps examples.
#'
#' @docType data
#' @name uscountygeojson
#' @usage uscountygeojson
#' @format A \code{list} in geojson format.
"uscountygeojson"
